Free (GPLv2) TCP/IP stack developed by TASS Belgium

Dependents:   lpc1768-picotcp-demo ZeroMQ_PicoTCP_Publisher_demo TCPSocket_HelloWorld_PicoTCP Pico_TCP_UDP_Test ... more

PicoTCP. Copyright (c) 2013 TASS Belgium NV.

Released under the GNU General Public License, version 2.

Different licensing models may exist, at the sole discretion of the Copyright holders.

Official homepage: http://www.picotcp.com

Bug tracker: https://github.com/tass-belgium/picotcp/issues

Development steps:

  • initial integration with mbed RTOS
  • generic mbed Ethernet driver
  • high performance NXP LPC1768 specific Ethernet driver
  • Multi-threading support for mbed RTOS
  • Berkeley sockets and integration with the New Socket API
  • Fork of the apps running on top of the New Socket API
  • Scheduling optimizations
  • Debugging/benchmarking/testing

Demo application (measuring TCP sender performance):

Import programlpc1768-picotcp-demo

A PicoTCP demo app testing the ethernet throughput on the lpc1768 mbed board.

Revision:
63:97f481e33cb2
Parent:
51:ab4529a384a6
--- a/modules/pico_dhcp_server.h	Mon Sep 16 12:07:35 2013 +0000
+++ b/modules/pico_dhcp_server.h	Thu Sep 19 12:38:53 2013 +0000
@@ -9,20 +9,35 @@
 #include "pico_dhcp_common.h"
 #include "pico_addressing.h"
 
-struct pico_dhcp_server_setting
+/* default configuration */ 
+#define OPENDNS (long_be(0xd043dede)) /* OpenDNS DNS server 208.67.222.222 */
+#define POOL_START long_be(0x00000064)
+#define POOL_END long_be(0x000000fe)
+#define LEASE_TIME long_be(0x00000078)
+
+struct pico_dhcpd_settings
 {
+  struct pico_device *dev;
+  struct pico_socket *s;
+  struct pico_ip4 my_ip;
+  struct pico_ip4 netmask;
   uint32_t pool_start;
   uint32_t pool_next;
   uint32_t pool_end;
   uint32_t lease_time;
-  struct pico_device *dev;
-  struct pico_socket *s;
-  struct pico_ip4 server_ip;
-  struct pico_ip4 netmask;
   uint8_t flags; /* unused atm */
 };
 
-/* required field: IP address of the interface to serve, only IPs of this network will be served. */
-int pico_dhcp_server_initiate(struct pico_dhcp_server_setting *dhcps);
+struct pico_dhcp_negotiation {
+  struct pico_dhcpd_settings *settings;
+  struct pico_ip4 ipv4;
+  struct pico_eth eth;
+  enum dhcp_negotiation_state state;
+  uint32_t xid;
+  uint32_t assigned_address;
+};
+
+/* required settings field: IP address of the interface to serve, only IPs of this network will be served. */
+int pico_dhcp_server_initiate(struct pico_dhcpd_settings *setting);
 
 #endif /* _INCLUDE_PICO_DHCP_SERVER */